@@ -25,7 +25,7 @@
 class Node;
 
 extern void syslist(Node* n);
-extern void syserr(char* fmt, ...);
+extern void syserr(const char* fmt, ...);
 extern void sysexit(int r);
 
 #endif // __SYSERR_H
